from typegenie import authenticator, Deployment
from examples.creds import USERNAME, PASSWORD


ACCOUNT_USERNAME = USERNAME
ACCOUNT_PASSWORD = PASSWORD

# Enabling sandbox environment. Ignore this!
authenticator.enable_sandbox()


# Authenticate with account credentials
authenticator.authenticate_account(username=ACCOUNT_USERNAME, password=ACCOUNT_PASSWORD)

# List existing deployments
deployments = Deployment.list()
print('List Deployments:', deployments)

deployment_id = 'my-new-deployment'
for idx in range(len(deployments)):
    deployment = deployments[idx]
    if deployment.id == deployment_id:
        # Delete existing client from the account. Note: Deletes it on the backend also.

        # (Safe) Deletion method 1
        deployment.delete()
        del deployment

        # (Unsafe) Deletion method 2
        deployment = deployments.pop(idx)
        del deployment
        # Notice that for `del deployment` to work (without needing `deployment.delete()`, all reference of
        # `deployment` must be removed. That is why we do `deployment.pop(idx)` to remove it's reference from the
        # list `deployments`. When in doubt, use `deployment.delete()` before calling `del deployment`
        break

# Create a new deployment
new_deployment = Deployment.create(deployment_id=deployment_id, metadata={'test': True})
print('New Deployment:', new_deployment)

# Delete a deployment
to_delete_deployment = Deployment.create(deployment_id='to-be-deleted', metadata={})
print('List Deployments (Before Deletion):', Deployment.list())
del to_delete_deployment
print('List Deployments (After Deletion):', Deployment.list())

# Get existing deployment
existing_deployment = Deployment.get(deployment_id=deployment_id)
print('Existing Deployment:', existing_deployment)

# Update metadata of existing deployment
existing_deployment.update(metadata={'Test': False, 'trial': 'yes'})
print('Updated Deployment:', existing_deployment)

# Get access token for a particular deployment
token_dict = Deployment.get_access_token(deployment_id=deployment_id)
print('Deployment Access Token:', token_dict)



from setuptools import setup, find_packages
from pathlib import Path

with (Path(__file__).parent / "README.md").open("r") as fh:
    long_description = fh.read()

src_dir = str(Path(__file__).parent)

setup(
    name='typegenie',
    version='0.1.5',
    url="https://github.com/abhitopia/TypeGenieApiClient",
    author="abhitopia",
    author_email="hi@typegenie.net",
    description='Client Library for TypeGenie API. Check out https://api.typegenie.net for more info.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages('src', include=['typegenie', 'typegenie.*']),
    # py_modules=[''],
    package_dir={'': 'src'},
    entry_points={'console_scripts': ['typegenie-cli=typegenie.__cli__:main']},
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3"
    ],
    install_requires=[
        "requests>=2.25.1",
        "click>= 8.0.1",
        "python-box>=5.3.0",
        "prompt_toolkit>=3.0.18",
        "colorama>=0.4.4"],
    # These are only required if you want to use the typegenie-cli, i.e. pip install typegenie[with-cli]
    # extras_require={
    #     'with-cli': ["click>= 8.0.1",
    #                  "python-box>=5.3.0",
    #                  "prompt_toolkit>=3.0.18",
    #                  "colorama>=0.4.4"],
    # }
)
